# Copyright 2017 John Reese
# Licensed under the MIT license

'''asyncio bridge to sqlite3'''

from sqlite3 import sqlite_version, sqlite_version_info

__version__ = '0.1.0'
__all__ = [
    '__version__',
    'sqlite_version',
    'sqlite_version_info',
]
